@@ -62,18 +62,18 @@ class Authenticate:
         else:
             handle_item(self.asset_meta['security'])
 
-    def oauth2_client_credentials(self):
+    def oauth2(self, grant_type):
         scopes = self.asset.get('scopes')
         if scopes:
             scopes = scopes.join(' ')
         data = {
-            'client_id': self.asset['client_id'],
-            'client_secret': self.asset['client_secret'],
             'scope': scopes,
-            'grant_type': 'client_credentials'
+            'grant_type': grant_type
         }
-
-        token_url = self.asset.get("token_url") or urljoin(self.url, self.asset_meta['token_endpoint'])
+        for key in ['client_id', 'client_secret', 'username', 'password']:
+            if key in self.asset:
+                data[key] = self.asset[key]
+        token_url = self.asset.get("token_url") or urljoin(self.url, self.asset_meta['security']['token_endpoint'])
         response = self.session.request("POST",
                                         token_url,
                                         data=data)
@@ -84,6 +84,11 @@ class Authenticate:
             access_token = response.json()['access_token']
             self.session.headers.update({"Authorization": "Bearer {}".format(access_token)})
 
+    def oauth2_client_credentials(self):
+        self.oauth2('client_credentials')
+
+    def oauth2_password(self):
+        self.oauth2('password')
 
 class WrappedSession(Session):
     """A wrapper for requests.Session to override 'verify' property, ignoring REQUESTS_CA_BUNDLE environment variable.
